//
//  SNGLeftMenuVC.swift
//  Nextgen Dev
//
//  Created by itsol on 4/13/20.
//  Copyright © 2020 Chinh.nd. All rights reserved.
//

import UIKit
import Nuke

class SNGLeftMenuVC: SNGBaseViewController {
    @IBOutlet weak var tvListMenu: UITableView!
    @IBOutlet weak var menuWrapper: UIView!
    @IBOutlet weak var hiCompanyName: UILabel!
    @IBOutlet weak var avatar: UIImageView!
    @IBOutlet weak var lblWelcome: UILabel!
    @IBOutlet weak var lblCompanyName: UILabel!
    @IBOutlet weak var companyInfo: UIView!
    
    let viewModelUser = SNGLoginVM()
    var data: SNGInforLeftMenuModel?
    override func viewDidLoad() {
        super.viewDidLoad()
        self.createData()
        self.showAnimate()
        self.view.backgroundColor = UIColor.black.withAlphaComponent(0.65)
        self.lblWelcome.text = "Global.Welcome".localized()
        let gesture = UITapGestureRecognizer(target: self, action:  #selector(self.onSelectUserInfor))
        self.companyInfo.addGestureRecognizer(gesture)
    }
    
    func createData() {
        tvListMenu.register(UINib(nibName: SNGItemLeftMenuTVC.className, bundle: nil), forCellReuseIdentifier: SNGItemLeftMenuTVC.className)
        tvListMenu.register(UINib(nibName: SNGSpaceTableViewCell.className, bundle: nil), forCellReuseIdentifier: SNGSpaceTableViewCell.className)
    }
    
    @objc func onSelectUserInfor(sender : UITapGestureRecognizer) {
        let storyboard = UIStoryboard(name: "SNGAccountInfo", bundle: nil)
        let viewController = storyboard.instantiateViewController(withIdentifier: "SNGAccountInfoVC") as! SNGAccountInfoVC
        navigationController?.pushViewController(viewController, animated: true)
        self.removeAnimate()
    }
    
    @IBAction func onSelectBack(_ sender: Any) {
        self.removeAnimate()
    }
    
    
    @IBAction func onSelectBackgroundBack(_ sender: Any) {
        self.removeAnimate()
    }
    
    func showAnimate() {
        self.menuWrapper.transform = CGAffineTransform(translationX: -200, y: 0)
        self.view.alpha = 0.0
        UIView.animate(withDuration: 0.2, animations: {
            self.view.alpha = 1.0
            self.menuWrapper.transform = CGAffineTransform(translationX: 0, y: 0)
        })
    }
    
    func removeAnimate() {
        UIView.animate(withDuration: 0.2, animations: {
            self.menuWrapper.transform = CGAffineTransform(translationX: -200, y: 0)
            self.view.alpha = 0.0
        }, completion: {(finished : Bool) in
            if(finished)
            {
                self.view.removeFromSuperview()
            }
        })
    }
}

extension SNGLeftMenuVC: UITableViewDataSource, UITableViewDelegate {
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        if let data = self.data {
            let countData = data.menus.count
            return countData + 4
        }
        return 4
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
       
        guard let data = self.data else {
            let cell = tableView.dequeueReusableCell(withIdentifier: SNGItemLeftMenuTVC.className, for: indexPath) as! SNGItemLeftMenuTVC
            if indexPath.row == 0 {
                cell.lbTitle.text = "Tiện ích"
                cell.imgIconView.image = UIImage(named: "ultilities-white")
            }
            else if indexPath.row == 1 {
                cell.lbTitle.text = "Cài đặt"
                cell.imgIconView.image = UIImage(named: "setting-white")
            }else if indexPath.row == 2 {
                cell.lbTitle.text = "Đăng xuất"
            }
            return cell
        }
        
        let countData = data.menus.count
        if countData != 0 && indexPath.row == countData {
            let tempcell = tableView.dequeueReusableCell(withIdentifier: SNGSpaceTableViewCell.className, for: indexPath) as! SNGSpaceTableViewCell
            return tempcell
        }
        
        let cell = tableView.dequeueReusableCell(withIdentifier: SNGItemLeftMenuTVC.className, for: indexPath) as! SNGItemLeftMenuTVC
            if indexPath.row == countData + 1 {
                cell.lbTitle.text = "Tiện ích"
                cell.imgIconView.image = UIImage(named: "ultilities-white")
            } else if indexPath.row == countData + 2 {
                cell.lbTitle.text = "Cài đặt"
                cell.imgIconView.image = UIImage(named: "setting-white")
            } else if indexPath.row == countData + 3{
                cell.lbTitle.text = "Đăng xuất"
            } else if indexPath.row != countData {
                let menuItem = data.menus[indexPath.row]
                cell.lbTitle.text = Global.langCode == "vi" ? menuItem.funcNameVi : menuItem.funcNameEn
                
//                switch menuItem.funcCode {
//                 case "ACCOUNT_GROUP":
//                     cell.imgIconView.image = UIImage(named: "credit-cards-white")
//                 case "USER_INFO_GROUP":
//                     cell.imgIconView.image = UIImage(named: "credit-cards")
//                 case "TRANSFER_GROUP":
//                     cell.imgIconView.image = UIImage(named: "transfer")
//                 case "BEN_GROUP":
//                     cell.imgIconView.image = UIImage(named: "credit-cards")
//                 case "TEMPLATE_GROUP":
//                     cell.imgIconView.image = UIImage(named: "credit-cards")
//                 case "Duyệt":
//                     cell.imgIconView.image = UIImage(named: "credit-cards")
//                 case "CARD_GROUP":
//                     cell.imgIconView.image = UIImage(named: "credit-cards-white")
//                 case "BILLING_GROUP":
//                     cell.imgIconView.image = UIImage(named: "invoice")
//                 case "FINANCIAL":
//                     cell.imgIconView.image = UIImage(named: "credit-cards")
//                 case "CURRENCY_TRANS":
//                     cell.imgIconView.image = UIImage(named: "moneyBag-white")
//                 case "HOME":
//                     cell.imgIconView.image = UIImage(named: "house-white")
//                 default:
//                     break
//                 }
                let temp: [String] = menuItem.icon.components(separatedBy: ",")
                if temp.count == 2 {
                    if let dataDecoded = Data(base64Encoded: temp[1] , options: .ignoreUnknownCharacters) {
                    if let decodedimage:UIImage = UIImage(data: dataDecoded) {
                       
                        cell.imgIconView.image = decodedimage
                    }
                }
                }
            }
        return cell
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        if let data = self.data {
            let countData = data.menus.count
            return (indexPath.row == countData && countData != 0) ? 1 : 50
        }
        return 1
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        let countData = self.data?.menus.count ?? 0
        if countData == 0 {
            if indexPath.row == 0 {
                //tiện ích
                let storyboard = UIStoryboard(name: "SNGUltilities", bundle: nil)
                let viewController = storyboard.instantiateViewController(withIdentifier: "SNGUltilitiesVC") as! SNGUltilitiesVC
                self.navigationController?.pushViewController(viewController, animated: true)
            } else if indexPath.row == 1 {
                let storyboard = UIStoryboard(name: "SNGSettings", bundle: nil)
                let viewController = storyboard.instantiateViewController(withIdentifier: "SNGSettingsVC") as! SNGSettingsVC
                
                self.navigationController?.pushViewController(viewController, animated: true)
            }
            else if indexPath.row == 2 {
                //đăng xuất
                let agreeAction = Action(with: "Global.Agree".localized(), style: .normalRed) {[weak self] in
                    guard let `self` = self else { return }
                            self.viewModelUser.logout()
                        self.viewModelUser.logout()
                         //đăng xuất
                         let storyboard = UIStoryboard(name: "SNGLogin", bundle: nil)
                         let viewController = storyboard.instantiateViewController(withIdentifier: "SNGLoginVC") as! SNGLoginVC
                         viewController.hidesBottomBarWhenPushed = true
                         viewController.navigationController?.hidesBottomBarWhenPushed = true
                         self.navigationController?.pushViewController(viewController, animated: true)
                }
                let closeAction = Action(with: "Global.Cancel".localized(), style: .normalGray) {}
                self.showPopupTemplate(title: "Global.Logout.Title".localized(), content:  "Global.Logout.Content".localized(), actions: [agreeAction, closeAction], axis: .vertical)
            }
        } else if indexPath.row == countData + 1 {
            let storyboard = UIStoryboard(name: "SNGUltilities", bundle: nil)
            let viewController = storyboard.instantiateViewController(withIdentifier: "SNGUltilitiesVC") as! SNGUltilitiesVC
            self.navigationController?.pushViewController(viewController, animated: true)
        } else if indexPath.row == countData + 2 {
            //cài đặt
            let storyboard = UIStoryboard(name: "SNGSettings", bundle: nil)
            let viewController = storyboard.instantiateViewController(withIdentifier: "SNGSettingsVC") as! SNGSettingsVC
            self.navigationController?.pushViewController(viewController, animated: true)
        }
        else if indexPath.row == countData + 3 {
            let agreeAction = Action(with: "Global.Agree".localized(), style: .normalRed) {[weak self] in
                guard let `self` = self else { return }
               self.viewModelUser.logout()
                //đăng xuất
                let storyboard = UIStoryboard(name: "SNGLogin", bundle: nil)
                let viewController = storyboard.instantiateViewController(withIdentifier: "SNGLoginVC") as! SNGLoginVC
                viewController.hidesBottomBarWhenPushed = true
                viewController.navigationController?.hidesBottomBarWhenPushed = true
                self.navigationController?.pushViewController(viewController, animated: true)
            }
            let closeAction = Action(with: "Global.Cancel".localized(), style: .normalGray) {}
            self.showPopupTemplate(title: "Global.Logout.Title".localized(), content:  "Global.Logout.Content".localized(), actions: [agreeAction, closeAction], axis: .vertical)
        }
        else if indexPath.row != countData {
            switch self.data!.menus[indexPath.row].funcCode {
            case "ACCOUNT_GROUP":
                let storyboard = UIStoryboard(name: "SNGAccount", bundle: nil)
                let viewController = storyboard.instantiateViewController(withIdentifier: "SNGAccountVC") as! SNGAccountVC
                self.navigationController?.pushViewController(viewController, animated: true)
            case "USER_INFO_GROUP":
                let storyboard = UIStoryboard(name: "SNGAccountInfo", bundle: nil)
                let viewController = storyboard.instantiateViewController(withIdentifier: "SNGAccountInfoVC") as! SNGAccountInfoVC
                
                self.navigationController?.pushViewController(viewController, animated: true)
            case "TRANSFER_GROUP":
              break
            case "BEN_GROUP":
                //NTH
                let storyboard = UIStoryboard(name: "SNGSettingBeneficiary", bundle: nil)
                let viewController = storyboard.instantiateViewController(withIdentifier: "SNGSettingBeneficiaryVC") as! SNGSettingBeneficiaryVC
                self.navigationController?.pushViewController(viewController, animated: true)
            case "TEMPLATE_GROUP":
                //MGD
                let storyboard = UIStoryboard(name: "SNGSettingTemplateFT", bundle: nil)
                let viewController = storyboard.instantiateViewController(withIdentifier: "SNGSettingTemplateFTVC") as! SNGSettingTemplateFTVC
                self.navigationController?.pushViewController(viewController, animated: true)
            case "Duyệt":
                let storyboard = UIStoryboard(name: "SNGApproval", bundle: nil)
                let viewController = storyboard.instantiateViewController(withIdentifier: "SNGApprovalVC") as! SNGApprovalVC
                self.navigationController?.pushViewController(viewController, animated: true)
            case "CARD_GROUP":
                let storyboard = UIStoryboard(name: "SNGCard", bundle: nil)
                let viewController = storyboard.instantiateViewController(withIdentifier: "SNGCard") as! SNGCardVC
                viewController.dataMenu = self.data!.menus[indexPath.row].children
                viewController.navigationController?.hidesBottomBarWhenPushed = true
                self.navigationController?.pushViewController(viewController, animated: true)
            case "BILLING_GROUP":
                let storyboard = UIStoryboard(name: "SNGBillPayment", bundle: nil)
                let viewController = storyboard.instantiateViewController(withIdentifier: "SNGBillPayment") as! SNGBillPaymentVC
                self.navigationController?.pushViewController(viewController, animated: true)
            case "FINANCIAL":
                let storyboard = UIStoryboard(name: "SNGFinancial", bundle: nil)
                let viewController = storyboard.instantiateViewController(withIdentifier: "SNGFinancial") as! SNGFinancialVC
                viewController.dataMenu = self.data!.menus[indexPath.row].children
                self.navigationController?.pushViewController(viewController, animated: true)
            case "APPROVE_TRANS":
                let storyboard = UIStoryboard(name: "SNGApproval", bundle: nil)
                let viewController = storyboard.instantiateViewController(withIdentifier: "SNGApproval") as! SNGApprovalVC
                viewController.dataMenu = self.data!.menus[indexPath.row].children
                self.navigationController?.pushViewController(viewController, animated: true)
            default:
                print(self.data!.menus[indexPath.row].funcCode)
                break
            }
        }
        
        self.removeAnimate()
//    }
    }
}
